import os.path
from ier_processor.utils import *
import re
from PIL import Image
import pytesseract
from datetime import datetime

class ExtractionResult:

    def __init__(self):
        self.error = False
        self.success = False
        self.error_count = 0
        self.success_count = 0


class ExtractionSuccess(ExtractionResult):

    def __init__(self, extracted_data):
        self.extracted_data = extracted_data
        self.success = True


    @property
    def data(self):
        return self.extracted_data


class ExtractionFailure(ExtractionResult):

    def __init__(self, original_data, error_message):
        self.original_data = original_data
        self.error_message = error_message
        self.success = False

    @property
    def data(self):
        return "E:" + self.error_message


class RegexExtractor:

    def __init__(self, r_exp, regex_group_to_extract=1, extracting_field_name=None):
        self.r_exp = r_exp
        self.compiled_regex = re.compile(self.r_exp)
        self.regex_group_to_extract = regex_group_to_extract
        self.extracting_field_name = extracting_field_name

    def apply_to(self, data):
        matching = self.compiled_regex.search(data)
        if matching:
            return ExtractionSuccess(matching.group(self.regex_group_to_extract))
        else:
            return ExtractionFailure(data, f"Could not extract [{self.extracting_field_name}] from [{data}] using [{self.r_exp}]")


class HeaderPage(ExtractionSuccess):

    def __init__(self, **kwargs):
        self.main_town_or_village = kwargs.get('main_town_or_village', ExtractionFailure("", "Could not extract main_town_or_village"))
        self.post_office = kwargs.get('post_office', ExtractionFailure("", "Could not extract post_office"))
        self.village_council = kwargs.get('village_council', ExtractionFailure("", "Could not extract village_council"))
        self.block = kwargs.get('block', ExtractionFailure("", "Could not extract block"))
        self.police_station = kwargs.get('police_station', ExtractionFailure("", "Could not extract police_station"))
        self.sub_division = kwargs.get('sub_division', ExtractionFailure("", "Could not extract sub_division"))
        self.district = kwargs.get('district', ExtractionFailure("", "Could not extract district"))
        self.pin_code = kwargs.get('pin_code', ExtractionFailure("", "Could not extract pin_code"))
        self.components = [
            self.main_town_or_village,
            self.post_office,
            self.village_council,
            self.block,
            self.police_station,
            self.sub_division,
            self.district,
            self.pin_code,
        ]

        success = [x.success for x in self.components]
        self.success_count = len(success)
        self.success = all(success)
        errors = [x.error_message for x in self.components if not x.success]
        self.errors = errors
        self.error_count = len(self.errors)

    @property
    def data(self):
        return_data = [str(self.error_count), str(self.success_count)]
        for field in self.components:
            if field.success:
                return_data.append(field.extracted_data)
            else:
                return_data.append(field.error_message)
        return "\t".join(return_data)


class VoterRecord(ExtractionSuccess):

    def __init__(self, **kwargs):

        self.name = kwargs.get('name', ExtractionFailure("", "Could not extract name"))
        self.father = kwargs.get('father', ExtractionFailure("", "Could not extract fathers name"))
        self.husband = kwargs.get('husband', ExtractionFailure("", "Could not extract husbands name"))
        self.house_number = kwargs.get('house_number', ExtractionFailure("", "Could not extract house_number"))
        self.epic = kwargs.get('epic', ExtractionFailure("", "Could not extract epic"))
        self.age = kwargs.get('age', ExtractionFailure("", "Could not extract age"))
        self.gender = kwargs.get('gender', ExtractionFailure("", "Could not extract gender"))

        father = self.father
        husband = self.husband
        if father.success or husband.success:
            if not father.success:
                self.father = ExtractionSuccess("")
            elif not husband.success:
                self.husband = ExtractionSuccess("")

        self.components = [
            self.name,
            self.father,
            self.husband,
            self.house_number,
            self.epic,
            self.age,
            self.gender,]
        success = [x.success for x in self.components]
        self.success_count = len(success)
        errors = [x.error_message for x in self.components if not x.success]
        self.errors = errors
        self.error_count = len(self.errors)


    @property
    def data(self):
        return_data = [str(self.error_count), str(self.success_count)]
        for field in self.components:
            if field.success:
                return_data.append(field.extracted_data)
            else:
                return_data.append(field.error_message)
        return "\t".join(return_data)

class ImageData:

    def __init__(self, file, binary_data):
        self.file = file
        self.constituency = None
        self.file_no = None
        self.page_no = None
        self.type = None
        self.record_no = None
        self.valid = False
        self.binary_data = binary_data
        file_type_regex = re.compile(r'(\w+)_F(\d+)_P(\d+)_T(\w+)_(\d+).png$')
        matching = file_type_regex.search(file)
        if matching:
            self.valid = True
            self.constituency = matching.group(1)
            self.file_no = matching.group(2)
            self.page_no = matching.group(3)
            self.type = matching.group(4)
            self.record_no = matching.group(5)

    @property
    def data(self):
        image_valid = 'ImageTypeValid' if self.valid else 'ImageTypeInvalid'
        components = [image_valid,
                      str(self.type),
                      str(self.constituency),
                      str(self.file_no),
                      str(self.page_no),
                      str(self.record_no) ]
        return "\t".join(components)

    def is_header(self):
        return self.valid and self.type == 'PDFHeader'

    def is_assembly(self):
        return self.valid and self.type == 'Assembly'

    def is_section(self):
        return self.valid and self.type == 'Section'

    def is_record(self):
        return self.valid and self.type == 'Record'


class ImageProcessor:

    def __init__(self, debug=False):
        from datetime import datetime
        ts = datetime.now().strftime('%Y%m%d_%H%M%S')
        prefix = f'z_image_processing_{ts}'
        self.debug = debug
        self.working_dir = create_working_directory(debug=self.debug, prefix= prefix)


    def _open_image_in_working_dir(self, image_path):
        file_location = os.path.join(self.working_dir, os.path.basename(image_path))
        copy_across_file_systems(image_path, file_location)
        return Image.open(file_location)


    def extract_image_text(self, image):
        custom_oem_psm_config = r'--oem 3 --psm 6'
        return pytesseract.image_to_string(image, config=custom_oem_psm_config)

    def extract_polling_area_text(self, file):
        polling_area_image = self._open_image_in_working_dir(file)
        polling_area_text = self.extract_image_text(polling_area_image)
        lines = polling_area_text.split("\n")
        lines = [x.strip() for x in lines if x.strip() != '']
        return lines

    def process_pdf_header_image(self, image_data):
        lines = self.extract_polling_area_text(image_data.file)
        if len(lines) < 8:
            lines.append([""] * 8 - len(lines))

        main_town_or_village, post_office, village_council, block, police_station, sub_division, district, pin_code = lines

        not_alphabets = '[^A-Z^a-z]'
        r_main_town_or_village = RegexExtractor(re.compile(f"Main Town or Village{not_alphabets}+(.*)"), extracting_field_name='main_town_or_village')
        r_post_office = RegexExtractor(re.compile(f"Post Office{not_alphabets}+(.*)"), extracting_field_name='post_office')
        r_village_council = RegexExtractor(re.compile(f"Village Council{not_alphabets}+(.*)"), extracting_field_name='village_council')
        r_block = RegexExtractor(re.compile(f"Block{not_alphabets}+(.*)"), extracting_field_name='block')
        r_police_station = RegexExtractor(re.compile(f"Police Station{not_alphabets}+(.*)"), extracting_field_name='police_station')
        r_sub_division = RegexExtractor(re.compile(f"Sub Division{not_alphabets}+(.*)"), extracting_field_name='sub_division')
        r_district = RegexExtractor(re.compile(f"District{not_alphabets}+(.*)"), extracting_field_name='district')
        r_pin_code = RegexExtractor(re.compile(f"Pin Code.*?([0-9]+)$"), extracting_field_name='pin_code')

        main_town_or_village = r_main_town_or_village.apply_to(main_town_or_village)
        post_office = r_post_office.apply_to(post_office)
        village_council = r_village_council.apply_to(village_council)
        block = r_block.apply_to(block)
        police_station = r_police_station.apply_to(police_station)
        sub_division = r_sub_division.apply_to(sub_division)
        district = r_district.apply_to(district)
        pin_code = r_pin_code.apply_to(pin_code)

        header_page = HeaderPage(main_town_or_village=main_town_or_village,
                                 post_office=post_office,
                                 village_council=village_council,
                                 block=block,
                                 police_station=police_station,
                                 sub_division=sub_division,
                                 district=district,
                                 pin_code=pin_code)
        return header_page

    def extract_epic_from_voter_box_image(self, voter_box_image):
        width, height = voter_box_image.size
        epic_box = 200, 2, width - 4, height + 24
        epic_box_image = voter_box_image.crop(epic_box)
        epic_text = self.extract_image_text(epic_box_image).strip()
        epic = epic_text
        epic = epic.replace("$", "S")
        epic = epic.replace("§", "S")
        epic = re.sub('[^A-Z0-9]', '', epic)
        return ExtractionSuccess(epic)


    def extract_voter_text(self, voter_box_image):
        voter_data = self.extract_image_text(voter_box_image)
        voter_lines = [v.replace("Photo is", "").replace("Available", "") for v in voter_data.split("\n")]
        voter_lines = [v for v in voter_lines if v.strip()]
        return voter_lines

    def process_voter_image(self, image_data):
        name_regex = RegexExtractor(re.compile(r'Name[^A-Z^a-z)]*(.*)'), regex_group_to_extract=1, extracting_field_name='name')
        house_number_regex = RegexExtractor(re.compile(r'House Number[^A-Z^a-z^0-9]*(.*)'), extracting_field_name='house_number')
        age_regex = RegexExtractor(re.compile(r"Age: (\d+)"), extracting_field_name='age')
        gender_regex = RegexExtractor(re.compile(r"Gender: (MALE|FEMALE)"), extracting_field_name='gender')

        from io import StringIO, BytesIO
        voter_box_image = Image.open(BytesIO(image_data.binary_data))
        epic = self.extract_epic_from_voter_box_image(voter_box_image)
        voter_lines = self.extract_voter_text(voter_box_image)
        collected_fields = {}
        for line in voter_lines:
            if "Father" in line:
                collected_fields['father'] = name_regex.apply_to(line)
            elif "Husband" in line:
                collected_fields['husband'] = name_regex.apply_to(line)
            elif "Name" in line:
                collected_fields['name'] = name_regex.apply_to(line)
            elif "House Number" in line:
                collected_fields['house_number'] = house_number_regex.apply_to(line)
            elif "Age" in line or "Gender" in line:
                collected_fields['age'] = age_regex.apply_to(line)
                collected_fields['gender'] = gender_regex.apply_to(line)

        collected_fields['epic'] = epic
        voter_record = VoterRecord(**collected_fields)
        return voter_record


    def process_assembly_image(self, image_data):
        assembly_extractor = RegexExtractor(re.compile("Assembly Constituency No and Name : (\\d+-)?(.*)"), 2, extracting_field_name='assembly')
        assembly_image = self._open_image_in_working_dir(image_data.file)
        assembly_image_text = self.extract_image_text(assembly_image)
        return assembly_extractor.apply_to(assembly_image_text)

    def process_section_header(self, image_data):
        section_extractor = RegexExtractor(re.compile("Section No and Name : (\\d+-)?(.*)"), 2, extracting_field_name='section')
        section_image = self._open_image_in_working_dir(image_data.file)
        section_image_text = self.extract_image_text(section_image)
        return section_extractor.apply_to(section_image_text)

    def process_image(self, file, binary_data = None):
        start = datetime.now()
        image_data = ImageData(file, binary_data)
        result = None
        if image_data.is_header():
            result = self.process_pdf_header_image(image_data)
        elif image_data.is_assembly():
            result = self.process_assembly_image(image_data)
        elif image_data.is_section():
            result = self.process_section_header(image_data)
        elif image_data.is_record():
            result = self.process_voter_image(image_data)
        else:
            raise Exception(f'Unknown File type {file}')
        end = datetime.now()
        duration = end - start
        print(f"processed {file} in {duration.total_seconds()} sec.")
        return image_data.type, "\t".join([image_data.data, result.data, image_data.file])


if __name__ == '__main__':
    if os.name == 'nt':
        pytesseract.pytesseract.tesseract_cmd = r'C:\Program Files\Tesseract-OCR\tesseract.exe'
    pdf_header_image = r"pdf_processing_workspace_3/pdf_pages_as_images/Benaulim/01/01/Benaulim_F01_P01_TPDFHeader_0.png"
    assembly_image = r"pdf_processing_workspace_3/pdf_pages_as_images/Benaulim/01/03/Benaulim_F01_P03_TAssembly_0.png"
    section_image = r"pdf_processing_workspace_3/pdf_pages_as_images/Benaulim/01/03/Benaulim_F01_P03_TSection_0.png"
    voter_image = r"pdf_processing_workspace_3/pdf_pages_as_images/Benaulim/01/03/Benaulim_F01_P03_TRecord_0.png"
    image_processor = ImageProcessor()
    result = image_processor.process_image(pdf_header_image)
    print(f'header_data is [{result.data}]')
    result = image_processor.process_image(assembly_image)
    print(f'assembly_data is [{result.data}]')
    result = image_processor.process_image(section_image)
    print(f'section_data is [{result.data}]')
    result = image_processor.process_image(voter_image)
    print(f'voter_data is [{result.data}]')




import boto3
import tempfile
import os
import re
import os.path
import shutil

from urllib.parse import urlparse


def create_working_directory(prefix, debug=False):
    working_dir_root = os.getcwd() if debug else None
    working_dir = tempfile.TemporaryDirectory(prefix=prefix, dir=working_dir_root).name
    os.makedirs(working_dir)
    return working_dir

def copy_across_file_systems(src, dest):

    def strip_starting_slash(s):
        return re.sub('^/*', '', s)

    src_url = urlparse(src)
    dest_url = urlparse(dest)

    src_aws = src_url.scheme == 's3' or src_url.scheme == 's3a'
    dest_aws = dest_url.scheme == 's3' or dest_url.scheme == 's3a'

    if src_aws and dest_aws:
        src_params = {'Bucket': src_url.netloc, 'Key': strip_starting_slash(src_url.path)}
        boto3.resource('s3').meta.client.copy(src_params, dest_url.netloc, strip_starting_slash(dest_url.path))
    elif src_aws:
        boto3.resource('s3').Bucket(src_url.netloc).download_file(strip_starting_slash(src_url.path), dest)
    elif dest_aws:
        dest_path = strip_starting_slash(dest_url.path).replace('\\', "/")
        print(f'copying {src} to {dest_path}')
        boto3.resource('s3').Bucket(dest_url.netloc).upload_file(src, dest_path)
    else:
        os.makedirs(os.path.dirname(dest), exist_ok=True)
        shutil.copy(src, dest)



from PIL import Image
import glob
import os.path
import pytesseract
import pdf2image
from ier_processor.utils import *
import shutil

from datetime import datetime


class PDFSlicingMachine:

    """
    # a pdf document contains records that we want to extract
    # the first page contains contains general info
    # the second page contains photos
    # records start rom the third page onwards
    # each record is printed in a rectangular slot
    """

    def __init__(self, debug=False):
        self.debug = debug



    def split_whole_pdf_into_pages(self, src_pdf_file, dest_dir, limit = None):
        """each page of the pdf file is an image
        the pdf has been created in this fashion to prevent parsing of the pdf using pdf parsing libraries
        we need to split the pdf into its constituent images and then process each of the page-image"""

        # the pdf file has a name like Aldona/Part01.pdf.
        # We want to extract "Aldona" as constituency and "01" as the constituency_file_id
        path_regex = re.compile(r'\W(\w+?)\WPart(\d\d).pdf')
        matching = path_regex.search(src_pdf_file)
        split_files = []
        if not matching:
            raise ValueError(f'Could not get constituency and constituency_page_id from path {src_pdf_file}. '
                             f'Expecting a file like Aldona\\Part01.pdf')
        else:
            constituency, constituency_file_id = (matching.group(1), matching.group(2)) if matching else (None, None)

            # the pdf might be located on aws s3 or local file system
            # create a local working dir and copy the pdf to it
            time_prefix = datetime.now().strftime('%Y%m%d_%H%M%S')
            working_dir_prefix = f'z_pdf_split_{time_prefix}_{constituency}_{constituency_file_id}'
            working_dir = create_working_directory(working_dir_prefix)

            pdf_path_in_working_directory = os.path.join(working_dir, os.path.basename(src_pdf_file))
            copy_across_file_systems(src_pdf_file, pdf_path_in_working_directory)

            # split pdf into images
            split_results_dir = working_dir + os.sep
            #import subprocess
            #subprocess.call([r'c:\Program Files\poppler-0.68.0\bin\pdfimages.exe',
            #                 '-png',
            #                 pdf_path_in_working_directory,
            #                 split_results_dir])


            split_params = { 'output_folder': split_results_dir, 'fmt': 'png', 'thread_count': 4 }
            if os.name == 'nt':
                split_params['poppler_path'] = r'c:\Program Files\poppler-0.68.0\bin'
            pdf2image.convert_from_path(pdf_path_in_working_directory, **split_params)

            # rename the pdf page images and copy the split pages to the destination
            # files should be renamed as {constituency}_F{file_no}_P{page_no}.png
            page_id_regex = re.compile(r'(\d+).png$')
            for i, split_image in enumerate(glob.glob(os.path.join(working_dir, '*.png'))):
                if limit and i >= limit:
                    break
                matching = page_id_regex.search(split_image)
                if matching:
                    page_id = matching.group(1)
                    file_dest_dir = os.path.join(dest_dir, 'pdf_pages_as_images', constituency, constituency_file_id,
                                            page_id)
                    dest_path = os.path.join(file_dest_dir, f'{constituency}_F{constituency_file_id}_P{page_id}.png')
                    copy_across_file_systems(split_image, dest_path)
                    split_files.append(dest_path)
                else:
                    print(f'ignoring file {split_image} in split directory. could not extract file_id')
        # split_dir.cleanup();
            #remove working dir
            if not self.debug:
                shutil.rmtree(working_dir)
        return split_files

    def assembly_image_boundaries(self):
        """the coordinates on the image that contain assembly information(e.g. Aldona)"""
        #return 50, 10, 790, 35
        return 60, 15, 880, 50

    def section_image_boundaries(self):
        """the coordinates of the image that contain section information(e.g. Portais)"""
        # return 50, 50, 790, 80
        return 60, 70, 880, 108

    #  (0,0)--------------------------> x
    #   |              ^
    #   |              | offset from top of page
    #   |              |
    #   |              V
    #   |         ---------------------------------------
    #   |        |  Record 0   |  Record 1  | Record 2   |
    #   |        |             |            |            |
    #   |        |             |            |            |
    #   |         ---------------------------------------
    #   |        |  Record 3   |  Record 4  |  Record 5  |
    #   |        |             |            |            |
    #   |        |             |            |            |
    #   |         ---------------------------------------
    #   |        |  Record 6   |  Record 7  | Record 8   |
    #   |        |             |            |            |
    #   V        |             |            |            |
    #   y        ---------------------------------------
    #            |  Record 9   |  Record 10 | Record 11  |
    #            |             |            |            |
    #            |             |            |            |
    #             ---------------------------------------
    #            |  Record 12  | Record 13 | Record 14   |
    #            |             |            |            |
    #            |             |            |            |
    #             ---------------------------------------

    def record_boundaries(self, record_number, page_number=2):
        """" a pdf file has multiple pages.
         first page contains general info, and pages 2 to 30 contain records.
         the layout on page 2 is slightly different from rest of the pages.
         on page 2, the margin from the top of the page is more than other pages."""
        row = record_number // 3
        column = record_number % 3

        offset_from_top = 141 if page_number == 3 else 115

        #offset_from_top = 141
        #offset_from_top = 84

        row_height = 195

        # this value is from trial and error
        #row_height_adjustment_factor = 0.8 if row < 3 else 1.5
        row_height_adjustment_factor = 0

        y_top = offset_from_top + row * (row_height + row_height_adjustment_factor)
        y_bottom = y_top + row_height + 2

        # the record width is not the same for each column
        columns = [
            (68, y_top, 569, y_bottom),
            (570, y_top, 1071, y_bottom),
            (1072, y_top, 1572, y_bottom)]

        return columns[column]

    #   def get_voter_page_voter_boundaries(i, page_number=2):
    #       i = i - 1
    #       row = i // 3
    #       column = i % 3

    #       y_index = row
    #       y_length = 140
    #       y_offset = (y_index * y_length)

    #       start_y = 102 if page_number == 2 else 84

    #       y_top = start_y + y_index * (145 + (0.8 if y_index < 3 else 1.5))
    #       y_bottom = y_top + 147

    #       columns = [
    #           (50, y_top, 428, y_bottom), (426, y_top, 808, y_bottom), (803, y_top, 1183, y_bottom)]

    #       p = columns[column]
    #       return p

    def polling_area_boundaries_fin(self):
        #return 534, 562, 1050, 787
        return 712, 764, 1218, 988

    def crop_image(self, img, image_coordinates):
        return img.crop(image_coordinates)

    def extract_image_text(self, image):
        custom_oem_psm_config = r'--oem 3 --psm 6'
        return pytesseract.image_to_string(image, config=custom_oem_psm_config)

    def save_image_as(self, image_object, image_name, working_dir, dest_dir):
        save_image_path = os.path.join(working_dir, image_name)
        image_object.save(save_image_path)
        dest_image_path = os.path.join(dest_dir, image_name)
        copy_across_file_systems(save_image_path, dest_image_path)

    def split_pdf_page_image_into_record_images(self, pdf_page_image_path, dest_base, limit = None):
        """the image h"""

        # the image has a name like Aldona_F1_P2.png where Aldona is the name of the constituency , F1 refers to File 1 of
        # Aldona constituency and P1 refers to page 1 of file 1

        file_name_regex = re.compile(r'(\w+)_F(\d+)_P(\d+).png$')
        matching = file_name_regex.search(pdf_page_image_path)
        if not matching:
            raise ValueError("Cannot extract constituency , file and page number from {pdf_page_image} . "
                             "Expecting a file name like Aldona_F3_P2.png")
        else:
            constituency, constituency_file_id, page_id = matching.group(1), matching.group(2), matching.group(3)
            time_prefix = datetime.now().strftime('%Y%m%d_%H%M%S')
            prefix = f'z_pdf_page_split_{time_prefix}_{constituency}_{constituency_file_id}_{page_id}'
            working_dir = create_working_directory(prefix, debug=self.debug)
            local_pdf_page_image_path = os.path.join(working_dir, os.path.basename(pdf_page_image_path))
            copy_across_file_systems(pdf_page_image_path, local_pdf_page_image_path)

            dest_dir = os.path.join(dest_base, 'pdf_pages_as_images', constituency, constituency_file_id, page_id)
            if page_id == '01' or page_id == '000':
                return self.process_header_page(constituency, constituency_file_id, dest_dir, local_pdf_page_image_path, page_id, working_dir)
            elif page_id == '02':
                pass
                return []
            else:
                return self.process_records_page(constituency, constituency_file_id, dest_dir, local_pdf_page_image_path, page_id, working_dir)
            if not self.debug:
                shutil.rmtree(working_dir)

    def process_header_page(self, constituency, constituency_file_id, dest_dir, local_pdf_page_image_path, page_id, working_dir):
        first_page = Image.open(local_pdf_page_image_path)
        polling_area_boundaries = self.polling_area_boundaries_fin()
        polling_area_image = self.crop_image(first_page, polling_area_boundaries)
        image_name = f'{constituency}_F{constituency_file_id}_P{page_id}_TPDFHeader_0.png'
        self.save_image_as(polling_area_image, image_name, working_dir, dest_dir)
        return [os.path.join(dest_dir, image_name)]

    def process_records_page(self, constituency, constituency_file_id, dest_dir, local_pdf_page_image_path, page_id,
                             working_dir):
        record_images = []
        page_image = Image.open(local_pdf_page_image_path)
        assembly_image = self.crop_image(page_image, self.assembly_image_boundaries())
        assembly_image_name = f'{constituency}_F{constituency_file_id}_P{page_id}_TAssembly_0.png'
        record_images.append(os.path.join(dest_dir))
        self.save_image_as(assembly_image, assembly_image_name, working_dir, dest_dir)
        section_image = self.crop_image(page_image, self.section_image_boundaries())
        section_image_name = f'{constituency}_F{constituency_file_id}_P{page_id}_TSection_0.png'
        self.save_image_as(section_image, section_image_name, working_dir, dest_dir)
        for i in range(30):
            page = page_id
            preceding_zeroes = re.compile('^0*')
            page = int(re.sub(preceding_zeroes, '', page))
            boundaries = self.record_boundaries(i, page_number=page)
            record_image = self.crop_image(page_image, boundaries)
            record_image_name = f'{constituency}_F{constituency_file_id}_P{page_id}_TRecord_{i}.png'
            self.save_image_as(record_image, record_image_name, working_dir, dest_dir)
            record_images.append(os.path.join(dest_dir, record_image_name))
        return record_images


if __name__ == "__main__":
    local_src_benaulim = r'test_data/whole_pdf/Benaulim/Part01.pdf'
    aws_src_benaulim = 's3://epicfiles/GER_2020/Benaulim/Part01.pdf'
    local_dest = r'.\pdf_processing_workspace_3'
    aws_dest = 's3://epicfiles/splits/'

    record_processor = PDFSlicingMachine()

    ###################### split into pages
    # local src and local dest
    record_processor.split_whole_pdf_into_pages(local_src_benaulim, local_dest)
    # aws src and aws dest
    # record_processor.split_whole_pdf_into_pages(aws_src_benaulim, aws_dest)


    #################### split page in records
    #local_header_page = 'pdf_processing_workspace_3/pdf_pages_as_images/Benaulim/01/01/Benaulim_F01_P01.png'
    #record_processor.split_pdf_page_image_into_record_images(local_header_page, local_dest)
    #local_record_page = 'pdf_processing_workspace_3/pdf_pages_as_images/Benaulim/01/07/Benaulim_F01_P07.png'
    #local_record_page = 'pdf_processing_workspace_3/pdf_pages_as_images/Benaulim/01/03/Benaulim_F01_P03.png'
    #local_record_page = 'pdf_processing_workspace_3/pdf_pages_as_images/Benaulim/01/007/Benaulim_F01_P007.png'
    #record_processor.split_pdf_page_image_into_record_images(local_record_page, local_dest)
